Module php — Inmanta 2017.4dev documentation

# Module php

> - License: Apache 2.0
> - Version: 0.3
> - Author: Inmanta <code@inmanta.com>
> - Upstream project: https://github.com/inmanta/php.git

## Entities

entity `php::Application`

  Parents: `web::Application`

  A web application that requires PHP

  attribute bool `php55w`=False

  The following implementations are defined for this entity:

  > - `php::phpApacheRPM`
  > - `php::php55el`
  > - `php::phpApacheDEB`

  The following implements statements select implementations for this entity:

  > - `php::phpApacheRPM` constraint `(std::familyof(host.os,'redhat') and (php55w == False))`
  > - `php::phpApacheDEB` constraint `std::familyof(host.os,'ubuntu')`
  > - `php::php55el` constraint `(std::familyof(host.os,'redhat') and (php55w == True))`

## Implementations

implementation `php::php55el`

  This modules installs a common set of php modules and support for webservers either through a plugin or a cgi like interface.

implementation `php::phpApacheDEB`

  This modules installs a common set of php modules and support for webservers either through a plugin or a cgi like interface.

implementation `php::phpApacheRPM`

  This modules installs a common set of php modules and support for webservers either through a plugin or a cgi like interface.